{% extends "pydata_sphinx_theme/layout.html" %}

{% set is_single_page = (theme_single_page == True) or (theme_single_page == "True") %}
{% if is_single_page %}
    {%- set sidebar_width_class = "col-md-2" %}
{% else %}
    {%- set sidebar_width_class = "col-md-3" %}
{% endif %}

<!-- Docs TOC is "d-none d-xl-block col-xl-2" -->
{% block docs_sidebar %}
<div class="col-12 {{ sidebar_width_class }} bd-sidebar site-navigation show{% if is_single_page %} single-page{% endif %}" id="site-navigation">
    {% if not is_single_page %}
        {% include "sidebar.html" %}
    {%- endif %}
</div>
{% endblock %}

{% block docs_main %}
<main class="col py-md-3 pl-md-4 bd-content overflow-auto" role="main">
    {% block docs_body %}
    {% include "topbar.html" %}
    <div id="main-content" class="row">
        <div class="col-12 col-md-9 pl-md-3 pr-md-0">
        {{ super() }}
        {% if theme_show_prev_next %}
            {% include "_templates/prev-next.html" %}
        {% endif %}
        </div>
    </div>
    {% endblock %}
    {%- include "footer.html" %}
</main>
{% endblock %}

{% block docs_toc %}
{% endblock %}

{% block docs_navbar %}
{%- endblock %}

{%- block footer %}
{%- endblock %}
