/*********************************************
* Left Nav Bar *
*********************************************/
#site-navigation  {
    height: 100vh !important;
    width: $leftbar-width;
    flex: auto;
    top: 0px !important;
    margin-left:0;
    overflow-y: auto;
    background: white;
    transition: margin-left .2s ease 0s, opacity .2s ease 0s, visibility .2s ease 0s;
    z-index: 2000 !important;

    // Over-ride bootstrap collapsing styles for a smooth transition
    &.collapse {
        visibility: hidden;
        margin-left: -$leftbar-width;
        opacity: 0;
        display: block;
        &.show {
            visibility: visible;
            margin-left: 0;
            opacity: 1;
        }
    }

    @include scrollbar-style();
    @media (max-width: $breakpoint-md) {
        position: fixed;
        margin-top: $topbar-height;
        border-right: 1px solid rgba(0,0,0,.1);

        // If we're only a single page, sidebar should hide at narrow widths.
        &.single-page {
            display: none;
        }
    }

    // Sidebar link color
    nav ul.nav {
        li a, ul li a {
            color: $non-content-grey;
        }
        a:hover, li.active > a, li.active > a:hover {
            color: rgba(var(--pst-color-link), 1);;
        }
    }

    h1.site-logo {
        margin: .5em 0 0 0;
        font-size: 1.1em;
        color: black;
        text-align: center;
    }

    div.navbar_extra_footer {
        text-align: center;
        font-size: .9em;
        color: $non-content-grey;
        margin-bottom: 3em;
    }

    // Single page
    &.single-page {
        border-right: 0;
    }
}

div.navbar-brand-box {
    @media (min-width: $breakpoint-md) {
        padding-top: 2em;
    }

    a.navbar-brand {
        width: 100%;
        height: auto;

        img {
            display: block;
            height: auto;
            width: auto;
            max-height:10vh;
            max-width: 100%;
            margin: 0 auto;
            @media (min-width: $breakpoint-md) {
                max-height: 15vh !important;
            }
        }
    }
}

nav.bd-links {
    margin-left: 0px;  // Because the PST adds margin by default
    p.caption, .toctree-l1 a {
        padding-left: 0em;
    }
    // Overriding PyData Theme Defaults so the navigation is always visible
    overflow-y: visible;
    max-height: none;
}

// Navbar and topbar sidebar padding should max at 300px
@media (min-width: $breakpoint-md) {
    .bd-sidebar {
        max-width: 275px;
    }
}
