# -- Project information -----------------------------------------------------

project = "Sphinx Book Theme"
copyright = "2020, Executable Book Project"
author = "Executable Book Project"

master_doc = "index"

extensions = ["myst_parser"]
html_theme = "sphinx_book_theme"

html_theme_options = {
    "home_page_in_toc": True,
}
