# Note: this should only be changed in src/jinja/theme.conf.j2
[theme]
inherit = pydata_sphinx_theme
pygments_style = tango
sidebars = sidebar-logo.html, search-field.html, sbt-sidebar-nav.html, sbt-sidebar-footer.html
stylesheet = {{ "src/scss/sphinx-book-theme.scss" | compiled_name }}?digest={{ "src/scss/sphinx-book-theme.scss" | hash }}

[options]
single_page = False
# DEPRECATE after a few release cycles
expand_toc_sections = []
path_to_docs =
repository_url =
repository_branch =
launch_buttons = {}
home_page_in_toc = False
logo_only =
# DEPRECATE after a few release cycles
navbar_footer_text =
extra_navbar = Theme by the <a href="https://ebp.jupyterbook.org">Executable Book Project</a>
extra_footer =
use_issues_button = False
use_download_button = True
use_fullscreen_button = True
use_repository_button = False
theme_dev_mode = False
show_navbar_depth = 1
toc_title = Contents
